#region Copyright Syncfusion Inc. 2001 - 2006
//
//  Copyright Syncfusion Inc. 2001 - 2006. All rights reserved.
//
//  Use of this code is subject to the terms of our license.
//  A copy of the current license can be obtained at any time by e-mailing
//  licensing@syncfusion.com. Any infringement will be prosecuted under
//  applicable laws. 
//
#endregion

using System;
using System.Drawing;
using System.Collections;
using System.ComponentModel;
using System.Windows.Forms;
using System.Data;
using System.Data.OleDb;
using System.IO;
using System.Text;
using System.Diagnostics;

using Syncfusion.Grouping;
using Syncfusion.Windows.Forms.Grid;
using Syncfusion.Windows.Forms.Grid.Grouping;

namespace GGC_HideTable
{
	/// <summary>
	/// GroupingEngineFactory provides GroupingRecordRow elements that
	/// support saving row heights.
	/// </summary>
	/// 
	public class GroupingEngineFactory : GridEngineFactoryBase
	{
		// Add this line in your forms ctor:
		// GroupingEngineFactory provides a modified GridChildTable that adds an extra section
		// GridEngineFactory.Factory = new GroupingEngineFactory();

		public override GridEngine CreateEngine()
		{
			return new GroupingEngine();
		}
	}

	public class GroupingEngine : GridEngine
	{
		public override ChildTable CreateChildTable(Element parent)
		{
			return new GroupingChildTable(parent);
		}
	}

	public class GroupingChildTable : GridChildTable, IGridGroupOptionsSource
	{
		public GroupingChildTable(Element parent):base(parent)
		{}
		
		public override int GetVisibleCount()
		{
			if( GetTableVisible())
				return base.GetVisibleCount();
			return 0;
		}
		public override double GetYAmountCount()
		{
			if( GetTableVisible())
				return base.GetYAmountCount();
			return 0;
		}
		public override double GetVisibleCustomCount()
		{
			if( GetTableVisible())
				return base.GetVisibleCustomCount();
			return 0;
		}
		private bool GetTableVisible()
		{
			if( this != null && this.Category != null 
				&& this.Category.ToString()  != string.Empty)
			{
				if( int.Parse(this.Category.ToString())%2 == 0 )
				{
					if(this.ParentTableDescriptor.Name == "FirstChildTable")
						return false;
				}
				else
				{
					if(this.ParentTableDescriptor.Name == "SecondChildTable")
						return false;
				}
			}
			if( this.FilteredRecords != null && this.FilteredRecords.Count == 0 )
				return false;
			return true;
		}
	}
}
